==> jc-1.4.0.tar.gz: javax/swing/JColorChooser__24AccessibleJColorChooser.h <==
// public class javax.swing.JColorChooser$AccessibleJColorChooser

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 382c59c30a6efee4 javax_swing_JColorChooser__24AccessibleJColorChooser
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JColorChooser__24AccessibleJColorChooser_H_
#define _JC_javax_swing_JColorChooser__24AccessibleJColorChooser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JColorChooser$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object;

typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct;
typedef const struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype;

// Class fields structure
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$class_fields;

// Constructors
extern void _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$method$_init$8f26f12d11073619(_jc_env *, struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object *, struct _jc_javax_swing_JColorChooser$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object *);
};

// Vtable
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods	javax_swing_JColorChooser__24AccessibleJColorChooser;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs {
	struct _jc_javax_swing_JColorChooser$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs {
    _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs	javax_swing_JColorChooser__24AccessibleJColorChooser;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs	javax_swing_JColorChooser__24AccessibleJColorChooser;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object {
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24AccessibleJColorChooser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24AccessibleJColorChooser_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JColorChooser__24AccessibleJColorChooser.h <==
// public class javax.swing.JColorChooser$AccessibleJColorChooser

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 382c59c30a6efee4 javax_swing_JColorChooser__24AccessibleJColorChooser
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JColorChooser__24AccessibleJColorChooser_H_
#define _JC_javax_swing_JColorChooser__24AccessibleJColorChooser_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JColorChooser$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object;

typedef struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct;
typedef const struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype;

// Class fields structure
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$fields_struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$class_fields;

// Constructors
extern void _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$method$_init$8f26f12d11073619(_jc_env *, struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vmethods	javax_swing_JColorChooser__24AccessibleJColorChooser;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs {
	struct _jc_javax_swing_JColorChooser$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs {
    _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_refs	javax_swing_JColorChooser__24AccessibleJColorChooser;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$sub_nonrefs	javax_swing_JColorChooser__24AccessibleJColorChooser;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$object {
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24AccessibleJColorChooser$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$vtype _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24AccessibleJColorChooser, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24AccessibleJColorChooser$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24AccessibleJColorChooser_H_ */
